1.17.6 — Rucio 1.2 documentation

# 1.17.6

## General

### Features

- Transfers: Threadpool package is obsolete, needs to be replaced by something newer in conveyor #63

### Enhancements

- Core & Internals: client_extract flag needs to be added to metalink list_Replicas #1353
- RSE Manager: Replacing single ‘raise’ from rsemgr by ‘raise e’ #1366
- Transfers: Add a activity, dest_rse policy in bulk_group_transfer #1394

### Bugs

- Core & Internals: list_replicas with rse_Expression and resolve_archive makes 2 files out of 1 #1352
- Core & Internals: list_replicas with schemes=None and schemes=[…] gives conflicting results #1379
- Transfers: Misleading error message from conveyor-transfer-submitter #1168

## Clients

### Enhancements

- Clients: clients: add option to create non-deterministic RSEs #1405

### Bugs

- RSE Manager: Upload fails to delete left-overs #1359

## WebUI

### Enhancements

- Life time model: WebUI page to list Liftetime Model exceptions #1367

### Bugs

- WebUI: Lifetime exception request interface doesn’t properly show errors #1295
- WebUI: WebUI : Wrong link to DDM Dashboard #1410